@@ -1060,18 +1060,22 @@ def find_last_trading_date(market="IN"):
         end_date = datetime.datetime.today().date()
         if market == "US":
             eod_candles = fetch_eod_candles(symbol="SPY", start_date=start_date, end_date=end_date)
-        else:
+        elif market == "IN":
             eod_candles = fetch_eod_candles(symbol="NIFTY 50", start_date=start_date, end_date=end_date)
+        else:
+            return datetime.datetime.today() - datetime.timedelta(days=1)
 
-        eod_df = pd.DataFrame(eod_candles)
-        eod_df['date'] = pd.to_datetime(eod_df["date"])
-        eod_df = eod_df.sort_values(by="date", ascending=True)
-        last_trading_date = eod_df.to_dict('records')[-1]["date"]
-        # last_trading_date = list(trade_collection.find({'symbol': 'NIFTY 50'}).sort('date', -1).limit(1))[0]['date']
+        if eod_candles:
+            eod_df = pd.DataFrame(eod_candles)
+            eod_df['date'] = pd.to_datetime(eod_df["date"])
+            eod_df = eod_df.sort_values(by="date", ascending=True)
+            last_trading_date = eod_df.to_dict('records')[-1]["date"]
+        else:
+            last_trading_date = datetime.datetime.today() - datetime.timedelta(days=1)
         return last_trading_date
     except Exception as e:
         print(f"Exception in fetching last trading date : {e}")
-        return last_trading_date
+        return datetime.datetime.today() - datetime.timedelta(days=1)
 
 
 def mg_insert_log(collection, file_name, log_level, log_message, request_id=None, strategy_id=None, user_id=None, log_traceback=None, api_route=None):
